package ch.std.jumpstart;

import java.net.InetAddress;
import java.net.URL;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.event.ApplicationReadyEvent;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Profile;
import org.springframework.context.event.EventListener;
import org.springframework.core.env.Environment;

import ch.std.jumpstart.beans.CitiesBean;
import ch.std.jumpstart.jpa.City;
import ch.std.jumpstart.repository.CityRepository;

@SpringBootApplication
public class JumpstartApplication {

	Logger logger = LoggerFactory.getLogger(JumpstartApplication.class);

	public static void main(String[] args) {
		SpringApplication.run(JumpstartApplication.class, args);
	}

	public JumpstartApplication(Environment environment) {
		this.environment = environment;
	}

	@Bean
	@Profile("!test")
	public CommandLineRunner setup(CityRepository repository) {
		return (args) -> {
			for (String city : CitiesBean.getCities()) {
				repository.save(new City(city));
			}
		};
	}

	@Value("#{servletContext.contextPath}")
    private String contextPath;
	
	private Environment environment;

	@EventListener(ApplicationReadyEvent.class)
	public void OnApplicationReadyEvent(ApplicationReadyEvent event) {
		try {
			String ip = InetAddress.getLocalHost().getHostAddress();
			int port = environment.getProperty("server.port", Integer.class, 8080);
			String host = InetAddress.getLocalHost().getHostName();
			//String contextPath = environment.getProperty("server.servlet.context-path", String.class, "/");
			String protocol = "http";
			URL accessURL = new URL(protocol, host, port, contextPath);
			logger.info("Access URL = " + accessURL);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
	}

}
